#
# spec file for package saxon6
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define resolverdir %{_sysconfdir}/java/resolver
Name:           saxon6
Version:        6.5.5
Release:        lp150.1.12
Summary:        The SAXON XSLT Processor from Michael Kay
License:        MPL-1.0
Group:          Productivity/Publishing/XML
Url:            http://saxon.sourceforge.net/
Source0:        http://download.sf.net/saxon/saxon6-5-5.zip
Source1:        %{name}.saxon.script
Source2:        %{name}.build.script
Source3:        %{name}.1
Source4:        http://www.xml.com/2000/08/09/xslt/StructXmlParser.java
# implementes batch based interface to saxon6, SUSE specific
Source5:        saxon6.saxon-batch.script
Patch2:         %{name}-cmdlinefix.patch
#PATCH-FIX-OPENSUSE: jdk7+ assumes ASCII as default encoding, so iso-8859-1 does not work by default
Patch3:         saxon-javac-encoding.patch
#PATCH-FIX-OPENSUSE: bnc#739498 - backport changes from com/icl/saxon/aelfred/XmlParser.java
# to older version released under more permissive license
Patch4:         saxon-add-fixes-from-com-isl-saxon-aelfred.patch
#PATCH-FIX-OPENSUSE: implements batch mode in which saxon is capable to proceed more files per one JVM launch
Patch5:         saxon6-batch.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  fop >= 0.20.1
BuildRequires:  java-devel
BuildRequires:  javapackages-tools
BuildRequires:  jdom >= 1.0
BuildRequires:  unzip
BuildRequires:  xml-commons-apis
Requires:       %{_sbindir}/update-alternatives
Requires:       jaxp_parser_impl
Provides:       jaxp_transform_impl = %{name}-%{version}
Provides:       saxon
BuildArch:      noarch

%description
The SAXON package is a collection of tools for processing XML
documents. The main components are:

* An XSLT processor, which implements the Version 1.0 XSLT and XPath
   Recommendations from the World Wide Web Consortium, found at
   http://www.w3.org/TR/1999/REC-xslt-19991116 and
   http://www.w3.org/TR/1999/REC-xpath-19991116 with a number of
   powerful extensions. This version of Saxon also includes many of
   the new features defined in the XSLT 1.1 working draft, but for
   conformance and portability reasons these are not available if
   the stylesheet header specifies version="1.0".

* A Java library, which supports a similar processing model to XSL,
   but allows full programming capability, which you need if you
   want to perform complex processing of the data or to access
   external services such as a relational database

* A slightly improved version of the Aelfred parser from Microstar.
   (But you can use SAXON with any SAX-compliant XML parser if you
   prefer).

So you can use SAXON by writing XSLT stylesheets, by writing Java
applications, or by any combination of the two.

%package        aelfred
Summary:        Java XML parser
Group:          Productivity/Publishing/XML
Requires:       xml-commons-apis
Provides:       saxon-aelfred

%description    aelfred
A slightly improved version of the AElfred Java XML parser from
Microstar.

%package        manual
Summary:        Manual for %{name}
Group:          Productivity/Publishing/XML

%description    manual
Manual for %{name}.

%package        javadoc
Summary:        Javadoc for %{name}
Group:          Productivity/Publishing/XML

%description    javadoc
Javadoc for %{name}.

%package        demo
Summary:        Demos for %{name}
Group:          Productivity/Publishing/XML
Requires:       %{name} = %{version}-%{release}

%description    demo
Demonstrations and samples for %{name}.

%package        fop
Summary:        FOP support for %{name}
Group:          Productivity/Publishing/XML
Requires:       %{name} = %{version}-%{release}
Requires:       fop >= 0.20.1
Provides:       saxon-fop

%description    fop
FOP support for %{name}.

%package        jdom
Summary:        JDOM support for %{name}
Group:          Productivity/Publishing/XML
Requires:       %{name} = %{version}-%{release}
Requires:       jdom >= 1.0
Provides:       saxon-jdom

%description    jdom
JDOM support for %{name}.

%package        scripts
Summary:        Utility scripts for %{name}
Group:          Productivity/Publishing/XML
Requires:       %{name} = %{version}-%{release}
Provides:       saxon-scripts

%description    scripts
Utility scripts for %{name}.

%prep
%setup -q -c
unzip -q source.zip
cp -p %{SOURCE2} ./build.xml
cp -p %{SOURCE4} XmlParser.java
%patch2
%patch3 -p1
%patch4
%patch5 -p1
cp XmlParser.java com/icl/saxon/aelfred/XmlParser.java
# cleanup unnecessary stuff we'll build ourselves
rm -rf *.jar docs/api

%build
# fixes the javadoc fail
export LC_ALL=en_US.ISO-8859-2
export CLASSPATH=%(build-classpath xml-commons-apis xmlgraphics-fop jdom)
ant \
  -Dant.build.javac.source=1.6 -Dant.build.javac.target=1.6 \
  -Dj2se.javadoc=%{_javadocdir}/java \
  -Dfop.javadoc=%{_javadocdir}/fop \
  -Djdom.javadoc=%{_javadocdir}/jdom

%install
# jars
mkdir -p %{buildroot}%{_javadir}
cp -p build/lib/saxon.jar %{buildroot}%{_javadir}/%{name}.jar
cp -p build/lib/saxon-aelfred.jar %{buildroot}%{_javadir}/%{name}-aelfred.jar
cp -p build/lib/saxon-fop.jar %{buildroot}%{_javadir}/%{name}-fop.jar
cp -p build/lib/saxon-jdom.jar %{buildroot}%{_javadir}/%{name}-jdom.jar

# javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr build/api/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

# demo
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -pr samples/* %{buildroot}%{_datadir}/%{name}
# scripts
mkdir -p %{buildroot}%{_bindir}
sed 's,__RESOLVERDIR__,%{resolverdir},' < %{SOURCE1} \
  > %{buildroot}%{_bindir}/%{name}
ln -s %{name} %{buildroot}%{_bindir}/saxon
sed 's,__RESOLVERDIR__,%{resolverdir},' < %{SOURCE5} \
  > %{buildroot}%{_bindir}/%{name}-batch

mkdir -p %{buildroot}%{_mandir}/man1
sed 's,__RESOLVERDIR__,%{resolverdir},' < %{SOURCE3} \
  > %{buildroot}%{_mandir}/man1/%{name}.1

# jaxp_transform_impl ghost symlink
mkdir -p %{buildroot}%{_sysconfdir}/alternatives/
ln -sf %{_sysconfdir}/alternatives/jaxp_transform_impl.jar %{buildroot}%{_javadir}/jaxp_transform_impl.jar

%post
update-alternatives --install %{_javadir}/jaxp_transform_impl.jar \
  jaxp_transform_impl %{_javadir}/%{name}.jar 25

%postun
if [ $1 -eq 0 ] ; then
  update-alternatives --remove jaxp_transform_impl %{_javadir}/%{name}.jar
fi

%files
%{_javadir}/%{name}.jar
%{_javadir}/%{name}.jar
%{_javadir}/jaxp_transform_impl.jar
%ghost %{_sysconfdir}/alternatives/jaxp_transform_impl.jar

%files aelfred
%{_javadir}/%{name}-aelfred*

%files fop
%{_javadir}/%{name}-fop*

%files jdom
%{_javadir}/%{name}-jdom*

%files manual
%doc doc/*.html

%files javadoc
%doc %{_javadocdir}/%{name}

%files demo
%{_datadir}/%{name}

%files scripts
%defattr(0755,root,root,0755)
%{_bindir}/%{name}
%{_bindir}/%{name}-batch
%{_bindir}/saxon
%attr(0644,root,root) %{_mandir}/man1/%{name}.1*

%changelog
* Mon Sep 18 2017 fstrba@suse.com
- Specify java source and target 1.6 to fix build with jdk9
* Fri May 19 2017 tchvatal@suse.com
- Do not require javapackage-tools
* Fri Jul 11 2014 tchvatal@suse.com
- Fix update-alternatives code.
* Fri Jun 27 2014 tchvatal@suse.com
- Fix build on SLE11
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Mon Aug 12 2013 mvyskocil@suse.com
- implement batch support for saxon: saxon-batch
  * requested by docu team
  * adds saxon6-batch script with new -batch/-style arguments, which
    allows to proceed more XML files per one JVM launch removing the
    bootleneck in docu build
* Thu Jul 11 2013 toms@opensuse.org
- Added Recommends for saxon6-scripts and xml-commons-resolver
  Usually Saxon6 is used by invocation from a Shell, thus it
  is more convenient to have the corresponding script installed
  already.
  Additionally, XML tools like Saxon needs also XML catalog support
  for mapping URIs to local paths (especially useful for DocBook users)
* Tue Dec  4 2012 mvyskocil@suse.com
- fix bnc#739498 - remove GPL covered com/icl/saxon/aelfred/XmlParser
  used the original permissive version from xml.com and backport few fixes
  of later version
  * saxon-add-fixes-from-com-isl-saxon-aelfred.patch
* Thu Nov 29 2012 mvyskocil@suse.com
- add saxon provides to make bnc#780666 really fixed
  * add saxon-$subpackage to some important subpackages too
* Thu Nov  8 2012 toms@opensuse.org
- Fixed saxon6 script (needs saxon6.jar)
* Wed Oct 31 2012 mvyskocil@suse.com
- reintroduce it as saxon6 again (bnc#780666)
  * requested and needed by documentation team
- add saxon-javac-encoding.patch fixes build under jdk7
* Wed Dec  2 2009 coolo@novell.com
- update patches, fix build
* Mon Mar 10 2008 anosek@suse.cz
- downgrade to version 6.5.5, moved Saxon 8.x to separate saxon8
  package
- based on the JPackage project, dropped two patches
  (tinytree.patch) (fragmentval.patch)
- Saxon 6 is needed because, for example, the DocBook stylesheets
  have some JAR files which contain extension functions written
  only for Saxon 6. These functions provide useful methods for
  DocBook processing. However, these are not compatible
  with the latest Saxon package.
* Wed Feb  6 2008 anosek@suse.cz
- BuildRequires: java-1.6.0-devel
* Wed May 23 2007 dbornkessel@suse.de
- make rpmllint happy:
  - delete windows '\r' from doc files
  - index jars
  - faster compiling
* Thu Mar 29 2007 dbornkessel@suse.de
- added unzip to build reqs
* Wed Oct  4 2006 dbornkessel@suse.de
- update to saxon 8.8
- build from source (no binary package)
* Tue Mar 21 2006 dbornkessel@suse.de
- removed setJava call in wrapper script (Bug #158699)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Feb 27 2004 pmladek@suse.cz
- updated to the version 6.5.3 [#35119]
  * fixes 28 bugs found in Saxon 6.5.2
- added a missing prebuilt optional saxon-fop.jar
- fixed path to saxon jars in README.SuSE
* Tue Feb 24 2004 hmacht@suse.de
- building as non-root
* Mon Nov 25 2002 pmladek@suse.cz
- added the script saxon to use StyleSheets [#21801]
- improved README.SuSE
- classes moved from /usr/lib to /usr/share
* Mon Aug  5 2002 pmladek@suse.cz
- updated to bugfix version 6.5.2
- small improvent in README.SuSE (run setJava with new better option)
* Wed Feb  6 2002 pmladek@suse.cz
- updated to version 6.5:
  * fixed number of bugs
  * important incompatible change for XSLT conformance reasons
  * you can find details on the page:
  file:/usr/share/doc/packages/saxon/doc/changes.html
- moved to noarch
* Wed Nov 28 2001 ke@suse.de
- Update to version 6.4.4:
  - 20%% performance boost.
  - Support JDOM.
- Provide convenience link (/usr/lib/saxon ->
  /usr/lib/saxon-%%{version}).
* Wed Nov 21 2001 pmladek@suse.cz
- requires changed from java2 to more universal jre1.3.x
- added README.SuSE
* Wed May 23 2001 ke@suse.de
- Initial SuSE package: Version 6.3; long pending bug partly resolved
  [#291].
